Re: [PATCH v2 5/5] get_sha1: drop object/refname ambiguity flag
On 01/08/2014 01:00 AM, Jeff King wrote:
Show 31 quoted lines
> Now that our object/refname ambiguity test is much faster
> (thanks to the previous commit), there is no reason for code
> like "cat-file --batch-check" to turn it off. Here are
> before and after timings with this patch (on git.git):
>
> $ git rev-list --objects --all | cut -d' ' -f1 >objects
>
> [with flag]
> $ best-of-five -i objects ./git cat-file --batch-check
> real 0m0.392s
> user 0m0.368s
> sys 0m0.024s
>
> [without flag, without speedup; i.e., pre-25fba78]
> $ best-of-five -i objects ./git cat-file --batch-check
> real 0m1.652s
> user 0m0.904s
> sys 0m0.748s
>
> [without flag, with speedup]
> $ best-of-five -i objects ./git cat-file --batch-check
> real 0m0.388s
> user 0m0.356s
> sys 0m0.028s
>
> So the new implementation does just as well as we did with
> the flag turning the whole thing off (better actually, but
> that is within the noise).
>
> Signed-off-by: Jeff King <peff@peff.net>
> [...]
Very nice. Correctness without a performance hit.
Michael
--
Michael Haggerty
mhagger@alum.mit.edu
http://softwareswirl.blogspot.com/